:py:mod:`piel.models.frequency.photonic.directional_coupler_length`
===================================================================

.. py:module:: piel.models.frequency.photonic.directional_coupler_length

.. autoapi-nested-parse::

   Translated from https://github.com/flaport/sax or https://github.com/flaport/photontorch/tree/master



Module Contents
---------------


Functions
~~~~~~~~~

.. autoapisummary::

   piel.models.frequency.photonic.directional_coupler_length.directional_coupler_with_length



.. py:function:: directional_coupler_with_length(length=1e-05, coupling=0.5, loss=0, neff=2.34, wl0=1.55e-06, ng=3.4, phase=0)
